==> google_applovin_unity_ads-2.2.7.tar.gz: example/android/app/src/main/kotlin/com/btcpiyush/ads/google_applovin_unity_ads_example/CustomGeoSdk.kt <==
package com.btcpiyush.ads.google_applovin_unity_ads_example

import android.app.Activity
import android.util.Log
import android.widget.Toast
import com.appharbr.sdk.configuration.AHSdkConfiguration
import com.appharbr.sdk.engine.*
import com.appharbr.sdk.engine.adformat.AdFormat
import com.appharbr.sdk.engine.listeners.AHListener
import com.appharbr.sdk.engine.listeners.OnAppHarbrInitializationCompleteListener
import com.applovin.mediation.MaxAdListener
import com.applovin.mediation.MaxRewardedAdListener
import com.applovin.mediation.ads.MaxAdView
import com.applovin.mediation.ads.MaxInterstitialAd
import com.applovin.mediation.ads.MaxRewardedAd
import com.applovin.sdk.AppLovinSdk
import com.btcpiyush.ads.google_applovin_unity_ads.GoogleApplovinUnityAdsPlugin.GeoedgeSdkFactory
import io.flutter.embedding.android.FlutterActivity
import java.util.*


data class CustomGeoSdk(val activity: FlutterActivity) : GeoedgeSdkFactory {

    override fun initializeGeoSdk(geoedgeSdkKey: String?) {
        if (geoedgeSdkKey.isNullOrEmpty()) {
            return@initializeGeoSdk
        }

        val ahSdkConfiguration = AHSdkConfiguration.Builder(geoedgeSdkKey)
            .withMuteAd(true)
            .build()

        AppHarbr.initialize(activity.applicationContext,
            ahSdkConfiguration,
            object : OnAppHarbrInitializationCompleteListener {
                override fun onSuccess() {
                    Toast.makeText(
                        activity,
                        "AppHarbr SDK Initialized Successfully",
                        Toast.LENGTH_SHORT
                    ).show()
                    Log.d("LOG", "AppHarbr SDK Initialized Successfully")
                }

                override fun onFailure(reason: InitializationFailureReason) {
                    Toast.makeText(
                        activity,
                        "AppHarbr SDK Initialized onFailure",
                        Toast.LENGTH_SHORT
                    ).show()
                    Log.e(
                        "LOG",
                        "AppHarbr SDK Initialization Failed: " + reason.readableHumanReason
                    )
                }
            })
    }

    override fun addBannerAd(maxAdView: MaxAdView?) {
        val ahListener =
            AHListener { view: Any?, unitId: String?, adFormat: AdFormat?, reasons: Array<AdBlockReason?>? ->
                Log.e(
                    "LOG",
                    "AppHarbr - onAdBlocked for: $unitId, AppHarbr Banner reason: " + Arrays.toString(
                        reasons
                    )
                )
            }

        maxAdView?.let {
            AppHarbr.addBannerView(AdSdk.MAX, maxAdView, activity.lifecycle, ahListener)
        }

    }

    override fun addInterstitialAdGeoSdk(
        mInterstitialAppLovinAd: MaxInterstitialAd,
        mInterstitialAppLovinCallback: MaxAdListener
    ): MaxAdListener? {
        val ahListener =
            AHListener { view: Any?, unitId: String?, adFormat: AdFormat?, reasons: Array<AdBlockReason?>? ->
                /*Toast.makeText(act, "AppHarbr - onAdBlocked for: $unitId, reason: " + Arrays.toString(
                    reasons
                ), Toast.LENGTH_SHORT ).show()
                Log.e(
                    "LOG",
                    "AppHarbr - onAdBlocked for: $unitId, reason: " + Arrays.toString(
                        reasons
                    )
                )*/
            }

        val callback = AppHarbr.addInterstitial(
            AdSdk.MAX,
            mInterstitialAppLovinAd,
            mInterstitialAppLovinCallback,
            activity.lifecycle,
            ahListener
        )

        return callback
    }

    override fun loadAppLovinInterstitial(
        activity: Activity,
        adUnitId: String,
        _appLovinSDK: AppLovinSdk,
        mInterstitialAppLovinCallback: MaxAdListener
    ): MaxInterstitialAd {

        val adview = MaxInterstitialAd(
            adUnitId, _appLovinSDK, activity
        )

        val ahListener =
            AHListener { view: Any?, unitId: String?, adFormat: AdFormat?, reasons: Array<AdBlockReason?>? ->
                Toast.makeText(
                    activity, "AppHarbr - onAdBlocked for: $unitId, reason: " + Arrays.toString(
                        reasons
                    ), Toast.LENGTH_SHORT
                ).show()
                Log.e(
                    "LOG",
                    "AppHarbr - onAdBlocked for: $unitId, reason: " + Arrays.toString(
                        reasons
                    )
                )
            }

        val ahWrapperListener: MaxAdListener? = AppHarbr.addInterstitial(
            AdSdk.MAX,
            adview,
            mInterstitialAppLovinCallback,
            null,
            ahListener
        )

        //Set ahWrapperListener and load Ad
        adview.setListener(ahWrapperListener)
        adview.loadAd()
        return adview
    }

/*
    override fun addInterstitialAdGeoSdk(
        mInterstitialAppLovinAd: MaxInterstitialAd,
        mInterstitialAppLovinCallback: MaxAdListener
    ) : MaxAdListener? {
   }
*/

    override fun isGeoAdShow(mInterstitialAppLovinAd: MaxInterstitialAd): Boolean {
        Toast.makeText(activity, "AppHarbr SDK isGeoAdShow", Toast.LENGTH_SHORT).show()

        if (!mInterstitialAppLovinAd.isReady) {
            return false
        }

        if (!mInterstitialAppLovinAd.isReady) {
            return false
        }

        return AppHarbr.getRewardedState(mInterstitialAppLovinAd) != AdStateResult.BLOCKED

    }

    override fun addRewardAdGeoSdk(
        mRewardedAppLovinAd: MaxRewardedAd,
        mRewardedAppLovinCallback: MaxRewardedAdListener
    ): MaxRewardedAdListener? {
        Toast.makeText(activity, "AppHarbr SDK addRewardAdGeoSdk", Toast.LENGTH_SHORT).show()
        val ahListener =
            AHListener { _: Any?, unitId: String?, _: AdFormat?, reasons: Array<AdBlockReason?>? ->
                /*Toast.makeText(act, "AppHarbr - AHListener for:AppHarbr $unitId, reason: " + Arrays.toString(
                    reasons
                ), Toast.LENGTH_SHORT).show()*/

                /*Log.d(




                        "LOG",
                        "AppHarbr - onAdBlocked for: AppHarbr $unitId, reason: " + Arrays.toString(
                            reasons
                        )
                    )*/
            }

        return AppHarbr.addRewardedAd(
            AdSdk.MAX,
            mRewardedAppLovinAd,
            mRewardedAppLovinCallback,
            activity.lifecycle,
            ahListener
        )
    }

}

==> google_applovin_unity_ads-2.3.11.tar.gz: example/android/app/src/main/kotlin/com/btcpiyush/ads/google_applovin_unity_ads_example/CustomGeoSdk.kt <==
package com.btcpiyush.ads.google_applovin_unity_ads_example

import android.util.Log
import android.widget.Toast
import com.appharbr.sdk.configuration.AHSdkConfiguration
import com.appharbr.sdk.engine.*
import com.appharbr.sdk.engine.adformat.AdFormat
import com.appharbr.sdk.engine.listeners.AHListener
import com.appharbr.sdk.engine.listeners.OnAppHarbrInitializationCompleteListener
import com.applovin.mediation.MaxAd
import com.applovin.mediation.MaxAdListener
import com.applovin.mediation.MaxRewardedAdListener
import com.applovin.mediation.ads.MaxAdView
import com.applovin.mediation.ads.MaxInterstitialAd
import com.applovin.mediation.ads.MaxRewardedAd
import com.btcpiyush.ads.google_applovin_unity_ads.GoogleApplovinUnityAdsPlugin.GeoedgeSdkFactory
import io.flutter.embedding.android.FlutterActivity
import java.util.*

data class CustomGeoSdk(val activity: FlutterActivity) : GeoedgeSdkFactory {

    override fun initializeGeoSdk(geoedgeSdkKey: String?, timeoutInSeconds: Long) {
        if (geoedgeSdkKey.isNullOrEmpty()) {
            return@initializeGeoSdk
        }
        Log.e( "initializeGeoSdk: ", " ========== = = = = =  =   timeoutInSeconds    ------    ${timeoutInSeconds}")
        val ahSdkConfiguration = AHSdkConfiguration.Builder(geoedgeSdkKey)
            .withMuteAd(true)
            .withInterstitialAdTimeLimit(timeoutInSeconds)
            .build()

        AppHarbr.initialize(activity.applicationContext,
            ahSdkConfiguration,
            object : OnAppHarbrInitializationCompleteListener {
                override fun onSuccess() {
                    Toast.makeText(
                        activity,
                        "AppHarbr SDK Initialized Successfully",
                        Toast.LENGTH_SHORT
                    ).show()
                    Log.e("LOG", "AppHarbr SDK Initialized Successfully")
                }

                override fun onFailure(reason: InitializationFailureReason) {
                    Toast.makeText(
                        activity,
                        "AppHarbr SDK Initialized onFailure",
                        Toast.LENGTH_SHORT
                    ).show()
                    Log.e(
                        "LOG",
                        "AppHarbr SDK Initialization Failed: " + reason.readableHumanReason
                    )
                }
            })
    }

    override fun addBannerAd(maxAdView: MaxAdView?) {
        val ahListener =
            AHListener { view: Any?, unitId: String?, adFormat: AdFormat?, reasons: Array<AdBlockReason?>? ->
                Log.e(
                    "LOG",
                    "AppHarbr - onAdBlocked for: $unitId, AppHarbr Banner reason: " + Arrays.toString(
                        reasons
                    )
                )
            }

        maxAdView?.let {
            AppHarbr.addBannerView(AdSdk.MAX, maxAdView, activity.lifecycle, ahListener)
        }

    }

    override fun isGeoAdShow(maxAdView: MaxAd, adId: String): Boolean {
        val result = AppHarbr.shouldBlockNativeAd(AdSdk.MAX, maxAdView, adId)
        return result.adStateResult !== AdStateResult.BLOCKED
    }

    override fun setGeoIntraListener(
        mInterstitialAppLovinAd: MaxInterstitialAd,
        mInterstitialAppLovinCallback: MaxAdListener
    ) {
        val ahListener =
            AHListener { view: Any?, unitId: String?, adFormat: AdFormat?, reasons: Array<AdBlockReason?>? -> }

        val callback = AppHarbr.addInterstitial(
            AdSdk.MAX,
            mInterstitialAppLovinAd,
            mInterstitialAppLovinCallback,
            activity.lifecycle,
            ahListener
        )

        mInterstitialAppLovinAd.setListener(callback)
    }

    override fun setGeoRewardListener(
        mRewardAppLovinAd: MaxRewardedAd,
        mRewardAppLovinCallback: MaxRewardedAdListener
    ) {
        val ahListener =
            AHListener { _: Any?, unitId: String?, _: AdFormat?, reasons: Array<AdBlockReason?>? -> }

        val ahWrapperListener: MaxRewardedAdListener? =
            AppHarbr.addRewardedAd(
                AdSdk.MAX,
                mRewardAppLovinAd,
                mRewardAppLovinCallback,
                activity.lifecycle,
                ahListener
            )

        //Set ahWrapperListener and load Ad
        mRewardAppLovinAd.setListener(ahWrapperListener)
    }

    override fun isGeoAdShow(mInterstitialAppLovinAd: MaxInterstitialAd): Boolean {
        if (!mInterstitialAppLovinAd.isReady) {
            return false
        }
        return AppHarbr.getInterstitialState(mInterstitialAppLovinAd) != AdStateResult.BLOCKED
    }

    override fun isGeoAdShow(mRewardAppLovinAd: MaxRewardedAd): Boolean {
        if (!mRewardAppLovinAd.isReady) {
            return false
        }
        return AppHarbr.getRewardedState(mRewardAppLovinAd) != AdStateResult.BLOCKED
    }

}
